# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: device_messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='device_messages.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('\n\034com.milaboratory.pm.messages'),
  serialized_pb=_b('\n\x15\x64\x65vice_messages.proto\"\x1e\n\x0bPingRequest\x12\x0f\n\x07request\x18\x01 \x02(\x03\"7\n\x0cPingResponse\x12\x0f\n\x07request\x18\x01 \x02(\x03\x12\x16\n\x0erandomResponse\x18\x02 \x02(\x03\"L\n\x0bPumpRequest\x12\x13\n\x0bpump1Volume\x18\x01 \x01(\r\x12\x13\n\x0bpump2Volume\x18\x02 \x01(\r\x12\x13\n\x0bpump3Volume\x18\x03 \x01(\r\"\x91\x01\n\x10ODMeasureRequest\x12\x0c\n\x04tube\x18\x01 \x02(\r\x12\x14\n\x0claserOnDelay\x18\x02 \x02(\r\x12\x15\n\rlaserOffDelay\x18\x03 \x02(\r\x12\x0e\n\x06\x63ycles\x18\x04 \x02(\r\x12\x0c\n\x04\x62ias\x18\x05 \x02(\r\x12\x11\n\tresistor1\x18\x06 \x02(\r\x12\x11\n\tresistor2\x18\x07 \x02(\r\"M\n\x11ODMeasureResponse\x12\x0c\n\x04onFS\x18\x01 \x02(\r\x12\x0c\n\x04onSS\x18\x02 \x02(\r\x12\r\n\x05offFS\x18\x03 \x02(\r\x12\r\n\x05offSS\x18\x04 \x02(\r\"E\n\x08TaskInfo\x12\x1d\n\ttaskState\x18\x01 \x02(\x0e\x32\n.TaskState\x12\x1a\n\x12stackHighWaterMark\x18\x02 \x02(\r\"\xb6\x01\n\x15GetSystemInfoResponse\x12\x1b\n\x08Task_Log\x18\x01 \x02(\x0b\x32\t.TaskInfo\x12\x1e\n\x0bTask_USBIn1\x18\x02 \x02(\x0b\x32\t.TaskInfo\x12\x1f\n\x0cTask_USBOut1\x18\x03 \x02(\x0b\x32\t.TaskInfo\x12 \n\rTask_USBROut1\x18\x04 \x02(\x0b\x32\t.TaskInfo\x12\x1d\n\nTask_Mixer\x18\x05 \x02(\x0b\x32\t.TaskInfo\"7\n\x12SetLedStateRequest\x12\x12\n\x03led\x18\x01 \x02(\x0e\x32\x05.MLED\x12\r\n\x05state\x18\x02 \x02(\x08\"I\n\x14SetMixerStateRequest\x12\r\n\x05state\x18\x01 \x02(\x08\x12\x0e\n\x06period\x18\x02 \x01(\r\x12\x12\n\npulseWidth\x18\x03 \x01(\r\"\x86\x01\n\x14SetServoStateRequest\x12\x0e\n\x06servo0\x18\x01 \x01(\r\x12\x0e\n\x06servo1\x18\x02 \x01(\r\x12\x0e\n\x06servo2\x18\x03 \x01(\r\x12\x0e\n\x06servo3\x18\x04 \x01(\r\x12\x0e\n\x06servo4\x18\x05 \x01(\r\x12\x0e\n\x06servo5\x18\x06 \x01(\r\x12\x0e\n\x06servo6\x18\x07 \x01(\r*\x8f\x01\n\x0bRequestType\x12\x08\n\x04Ping\x10\x02\x12\x11\n\rGetSystemInfo\x10\x05\x12\x08\n\x04Pump\x10\t\x12\x0f\n\x0bSetLedState\x10\n\x12\x11\n\rSetServoState\x10\x0b\x12\r\n\tODMeasure\x10\x0c\x12\x11\n\rSetMixerState\x10\r\x12\x13\n\x0f\x45nterBootloader\x10\x64*L\n\tTaskState\x12\t\n\x05Ready\x10\x01\x12\x0b\n\x07Running\x10\x02\x12\x0b\n\x07\x42locked\x10\x03\x12\r\n\tSuspended\x10\x04\x12\x0b\n\x07\x44\x65leted\x10\x05*\x0f\n\x04MLED\x12\x07\n\x03RED\x10\x00\x42\x1e\n\x1c\x63om.milaboratory.pm.messages')
)

_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='RequestType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Ping', index=0, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GetSystemInfo', index=1, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Pump', index=2, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SetLedState', index=3, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SetServoState', index=4, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ODMeasure', index=5, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SetMixerState', index=6, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EnterBootloader', index=7, number=100,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=945,
  serialized_end=1088,
)
_sym_db.RegisterEnumDescriptor(_REQUESTTYPE)

RequestType = enum_type_wrapper.EnumTypeWrapper(_REQUESTTYPE)
_TASKSTATE = _descriptor.EnumDescriptor(
  name='TaskState',
  full_name='TaskState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Ready', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Running', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Blocked', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Suspended', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Deleted', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1090,
  serialized_end=1166,
)
_sym_db.RegisterEnumDescriptor(_TASKSTATE)

TaskState = enum_type_wrapper.EnumTypeWrapper(_TASKSTATE)
_MLED = _descriptor.EnumDescriptor(
  name='MLED',
  full_name='MLED',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RED', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1168,
  serialized_end=1183,
)
_sym_db.RegisterEnumDescriptor(_MLED)

MLED = enum_type_wrapper.EnumTypeWrapper(_MLED)
Ping = 2
GetSystemInfo = 5
Pump = 9
SetLedState = 10
SetServoState = 11
ODMeasure = 12
SetMixerState = 13
EnterBootloader = 100
Ready = 1
Running = 2
Blocked = 3
Suspended = 4
Deleted = 5
RED = 0



_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='PingRequest.request', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=55,
)


_PINGRESPONSE = _descriptor.Descriptor(
  name='PingResponse',
  full_name='PingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='PingResponse.request', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='randomResponse', full_name='PingResponse.randomResponse', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=112,
)


_PUMPREQUEST = _descriptor.Descriptor(
  name='PumpRequest',
  full_name='PumpRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pump1Volume', full_name='PumpRequest.pump1Volume', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pump2Volume', full_name='PumpRequest.pump2Volume', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pump3Volume', full_name='PumpRequest.pump3Volume', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=190,
)


_ODMEASUREREQUEST = _descriptor.Descriptor(
  name='ODMeasureRequest',
  full_name='ODMeasureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tube', full_name='ODMeasureRequest.tube', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='laserOnDelay', full_name='ODMeasureRequest.laserOnDelay', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='laserOffDelay', full_name='ODMeasureRequest.laserOffDelay', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cycles', full_name='ODMeasureRequest.cycles', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bias', full_name='ODMeasureRequest.bias', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resistor1', full_name='ODMeasureRequest.resistor1', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resistor2', full_name='ODMeasureRequest.resistor2', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=338,
)


_ODMEASURERESPONSE = _descriptor.Descriptor(
  name='ODMeasureResponse',
  full_name='ODMeasureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='onFS', full_name='ODMeasureResponse.onFS', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onSS', full_name='ODMeasureResponse.onSS', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offFS', full_name='ODMeasureResponse.offFS', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offSS', full_name='ODMeasureResponse.offSS', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=417,
)


_TASKINFO = _descriptor.Descriptor(
  name='TaskInfo',
  full_name='TaskInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='taskState', full_name='TaskInfo.taskState', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stackHighWaterMark', full_name='TaskInfo.stackHighWaterMark', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=488,
)


_GETSYSTEMINFORESPONSE = _descriptor.Descriptor(
  name='GetSystemInfoResponse',
  full_name='GetSystemInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Task_Log', full_name='GetSystemInfoResponse.Task_Log', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Task_USBIn1', full_name='GetSystemInfoResponse.Task_USBIn1', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Task_USBOut1', full_name='GetSystemInfoResponse.Task_USBOut1', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Task_USBROut1', full_name='GetSystemInfoResponse.Task_USBROut1', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Task_Mixer', full_name='GetSystemInfoResponse.Task_Mixer', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=673,
)


_SETLEDSTATEREQUEST = _descriptor.Descriptor(
  name='SetLedStateRequest',
  full_name='SetLedStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='led', full_name='SetLedStateRequest.led', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='SetLedStateRequest.state', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=675,
  serialized_end=730,
)


_SETMIXERSTATEREQUEST = _descriptor.Descriptor(
  name='SetMixerStateRequest',
  full_name='SetMixerStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='SetMixerStateRequest.state', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='period', full_name='SetMixerStateRequest.period', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pulseWidth', full_name='SetMixerStateRequest.pulseWidth', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=805,
)


_SETSERVOSTATEREQUEST = _descriptor.Descriptor(
  name='SetServoStateRequest',
  full_name='SetServoStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servo0', full_name='SetServoStateRequest.servo0', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='servo1', full_name='SetServoStateRequest.servo1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='servo2', full_name='SetServoStateRequest.servo2', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='servo3', full_name='SetServoStateRequest.servo3', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='servo4', full_name='SetServoStateRequest.servo4', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='servo5', full_name='SetServoStateRequest.servo5', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='servo6', full_name='SetServoStateRequest.servo6', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=942,
)

_TASKINFO.fields_by_name['taskState'].enum_type = _TASKSTATE
_GETSYSTEMINFORESPONSE.fields_by_name['Task_Log'].message_type = _TASKINFO
_GETSYSTEMINFORESPONSE.fields_by_name['Task_USBIn1'].message_type = _TASKINFO
_GETSYSTEMINFORESPONSE.fields_by_name['Task_USBOut1'].message_type = _TASKINFO
_GETSYSTEMINFORESPONSE.fields_by_name['Task_USBROut1'].message_type = _TASKINFO
_GETSYSTEMINFORESPONSE.fields_by_name['Task_Mixer'].message_type = _TASKINFO
_SETLEDSTATEREQUEST.fields_by_name['led'].enum_type = _MLED
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingResponse'] = _PINGRESPONSE
DESCRIPTOR.message_types_by_name['PumpRequest'] = _PUMPREQUEST
DESCRIPTOR.message_types_by_name['ODMeasureRequest'] = _ODMEASUREREQUEST
DESCRIPTOR.message_types_by_name['ODMeasureResponse'] = _ODMEASURERESPONSE
DESCRIPTOR.message_types_by_name['TaskInfo'] = _TASKINFO
DESCRIPTOR.message_types_by_name['GetSystemInfoResponse'] = _GETSYSTEMINFORESPONSE
DESCRIPTOR.message_types_by_name['SetLedStateRequest'] = _SETLEDSTATEREQUEST
DESCRIPTOR.message_types_by_name['SetMixerStateRequest'] = _SETMIXERSTATEREQUEST
DESCRIPTOR.message_types_by_name['SetServoStateRequest'] = _SETSERVOSTATEREQUEST
DESCRIPTOR.enum_types_by_name['RequestType'] = _REQUESTTYPE
DESCRIPTOR.enum_types_by_name['TaskState'] = _TASKSTATE
DESCRIPTOR.enum_types_by_name['MLED'] = _MLED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), dict(
  DESCRIPTOR = _PINGREQUEST,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:PingRequest)
  ))
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), dict(
  DESCRIPTOR = _PINGRESPONSE,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:PingResponse)
  ))
_sym_db.RegisterMessage(PingResponse)

PumpRequest = _reflection.GeneratedProtocolMessageType('PumpRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUMPREQUEST,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:PumpRequest)
  ))
_sym_db.RegisterMessage(PumpRequest)

ODMeasureRequest = _reflection.GeneratedProtocolMessageType('ODMeasureRequest', (_message.Message,), dict(
  DESCRIPTOR = _ODMEASUREREQUEST,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:ODMeasureRequest)
  ))
_sym_db.RegisterMessage(ODMeasureRequest)

ODMeasureResponse = _reflection.GeneratedProtocolMessageType('ODMeasureResponse', (_message.Message,), dict(
  DESCRIPTOR = _ODMEASURERESPONSE,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:ODMeasureResponse)
  ))
_sym_db.RegisterMessage(ODMeasureResponse)

TaskInfo = _reflection.GeneratedProtocolMessageType('TaskInfo', (_message.Message,), dict(
  DESCRIPTOR = _TASKINFO,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:TaskInfo)
  ))
_sym_db.RegisterMessage(TaskInfo)

GetSystemInfoResponse = _reflection.GeneratedProtocolMessageType('GetSystemInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSYSTEMINFORESPONSE,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:GetSystemInfoResponse)
  ))
_sym_db.RegisterMessage(GetSystemInfoResponse)

SetLedStateRequest = _reflection.GeneratedProtocolMessageType('SetLedStateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETLEDSTATEREQUEST,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:SetLedStateRequest)
  ))
_sym_db.RegisterMessage(SetLedStateRequest)

SetMixerStateRequest = _reflection.GeneratedProtocolMessageType('SetMixerStateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETMIXERSTATEREQUEST,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:SetMixerStateRequest)
  ))
_sym_db.RegisterMessage(SetMixerStateRequest)

SetServoStateRequest = _reflection.GeneratedProtocolMessageType('SetServoStateRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSERVOSTATEREQUEST,
  __module__ = 'device_messages_pb2'
  # @@protoc_insertion_point(class_scope:SetServoStateRequest)
  ))
_sym_db.RegisterMessage(SetServoStateRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
