# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network_messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='network_messages.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('\n\034com.milaboratory.pm.messages'),
  serialized_pb=_b('\n\x16network_messages.proto\"j\n\tReplyInfo\x12\x19\n\x11\x65xecutionNanoTime\x18\x01 \x02(\x04\x12\r\n\x05\x65rror\x18\x02 \x02(\x08\x12\x1d\n\terrorType\x18\x03 \x01(\x0e\x32\n.ErrorType\x12\x14\n\x0c\x65rrorMessage\x18\x04 \x01(\t*W\n\tErrorType\x12\x10\n\x0cNoSuchDevice\x10\x00\x12\x14\n\x10\x44\x65viceReplyError\x10\x01\x12\x10\n\x0cUnknownError\x10\x02\x12\x10\n\x0c\x44isconnected\x10\x03\x42\x1e\n\x1c\x63om.milaboratory.pm.messages')
)

_ERRORTYPE = _descriptor.EnumDescriptor(
  name='ErrorType',
  full_name='ErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NoSuchDevice', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DeviceReplyError', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownError', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Disconnected', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=134,
  serialized_end=221,
)
_sym_db.RegisterEnumDescriptor(_ERRORTYPE)

ErrorType = enum_type_wrapper.EnumTypeWrapper(_ERRORTYPE)
NoSuchDevice = 0
DeviceReplyError = 1
UnknownError = 2
Disconnected = 3



_REPLYINFO = _descriptor.Descriptor(
  name='ReplyInfo',
  full_name='ReplyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionNanoTime', full_name='ReplyInfo.executionNanoTime', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='ReplyInfo.error', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorType', full_name='ReplyInfo.errorType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='ReplyInfo.errorMessage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=132,
)

_REPLYINFO.fields_by_name['errorType'].enum_type = _ERRORTYPE
DESCRIPTOR.message_types_by_name['ReplyInfo'] = _REPLYINFO
DESCRIPTOR.enum_types_by_name['ErrorType'] = _ERRORTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReplyInfo = _reflection.GeneratedProtocolMessageType('ReplyInfo', (_message.Message,), dict(
  DESCRIPTOR = _REPLYINFO,
  __module__ = 'network_messages_pb2'
  # @@protoc_insertion_point(class_scope:ReplyInfo)
  ))
_sym_db.RegisterMessage(ReplyInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
